DEISM Documentation
===================

**Diffraction Enhanced Image Source Method - Arbitrary Room Geometry (DEISM-ARG)**

DEISM is a Python package for room acoustics simulation that incorporates local diffraction effects around transducers using the image source method.

Quick Links
-----------

* :ref:`academic-publications` - Jump to all publications
* :ref:`main-paper` - Main JASA paper
* :ref:`directivity-paper` - Directivity formulation paper  
* :ref:`iwaenc-paper` - Arbitrary geometries paper

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   workflows
   examples
   api_reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search` 